@@ -6,12 +6,15 @@
 #define	_REENTRANT			/* for Sun */
 #define __EXTENSIONS__                  /* for Sun */
 
-#include "asn1/asn1c/asn_internal.h"
 #include "asn1/asn1c/GeneralizedTime.h"
 
 #include <assert.h>
 #include <errno.h>
 
+#include "asn1/asn1c/asn_internal.h"
+#include "asn1/asn1c/xer_encoder.h"
+#include "json_util.h"
+
 #define	ATZVARS do {							\
 	char tzoldbuf[64];						\
 	char *tzold
@@ -52,35 +55,15 @@ static const ber_tlv_tag_t asn_DEF_GeneralizedTime_tags[] = {
 	(ASN_TAG_CLASS_UNIVERSAL | (26 << 2)),  /* [UNIVERSAL 26] IMPLICIT ...*/
 	(ASN_TAG_CLASS_UNIVERSAL | (4 << 2))    /* ... OCTET STRING */
 };
-static asn_per_constraints_t asn_DEF_GeneralizedTime_per_constraints = {
-	{ APC_CONSTRAINED, 7, 7, 0x20, 0x7e },  /* Value */
-	{ APC_SEMI_CONSTRAINED, -1, -1, 0, 0 }, /* Size */
-	0, 0
-};
 asn_TYPE_operation_t asn_OP_GeneralizedTime = {
 	OCTET_STRING_free,
 	GeneralizedTime_print,
 	GeneralizedTime_compare,
 	OCTET_STRING_decode_ber,    /* Implemented in terms of OCTET STRING */
 	GeneralizedTime_encode_der,
-	OCTET_STRING_decode_xer_utf8,
+	GeneralizedTime_encode_json,
 	GeneralizedTime_encode_xer,
-#ifdef	ASN_DISABLE_OER_SUPPORT
-	0,
-	0,
-#else
-	OCTET_STRING_decode_oer,
-	OCTET_STRING_encode_oer,
-#endif  /* ASN_DISABLE_OER_SUPPORT */
-#ifdef	ASN_DISABLE_PER_SUPPORT
-	0,
-	0,
-#else
-	OCTET_STRING_decode_uper,
-	OCTET_STRING_encode_uper,
-#endif	/* ASN_DISABLE_PER_SUPPORT */
-	GeneralizedTime_random_fill,
-	0	/* Use generic outmost tag fetcher */
+	NULL	/* Use generic outmost tag fetcher */
 };
 asn_TYPE_descriptor_t asn_DEF_GeneralizedTime = {
 	"GeneralizedTime",
@@ -92,13 +75,24 @@ asn_TYPE_descriptor_t asn_DEF_GeneralizedTime = {
 	asn_DEF_GeneralizedTime_tags,
 	sizeof(asn_DEF_GeneralizedTime_tags)
 	  / sizeof(asn_DEF_GeneralizedTime_tags[0]),
-	{ 0, &asn_DEF_GeneralizedTime_per_constraints, GeneralizedTime_constraint },
-	0, 0,	/* No members */
-	0	/* No specifics */
+	{ NULL, NULL, GeneralizedTime_constraint },
+	NULL, 0,	/* No members */
+	NULL	/* No specifics */
 };
 
 #endif	/* ASN___INTERNAL_TEST_MODE */
 
+static int
+GeneralizedTime2str(const GeneralizedTime_t *st, char *str)
+{
+	struct tm tm;
+
+	if (asn_GT2time(st, &tm) != 0)
+		return -1;
+
+	return asn_tm2str(&tm, str);
+}
+
 /*
  * Check that the time looks like the time.
  */
@@ -135,7 +129,7 @@ GeneralizedTime_encode_der(const asn_TYPE_descriptor_t *td, const void *sptr,
 		ASN__ENCODE_FAILED;
     }
 
-    st = asn_time2GT_frac(0, &tm, fv, fd); /* Save time */
+    st = asn_time2GT_frac(NULL, &tm, fv, fd); /* Save time */
     if(!st) ASN__ENCODE_FAILED;               /* Memory allocation failure. */
 
     erval = OCTET_STRING_encode_der(td, st, tag_mode, tag, cb, app_key);
@@ -145,11 +139,26 @@ GeneralizedTime_encode_der(const asn_TYPE_descriptor_t *td, const void *sptr,
     return erval;
 }
 
+json_t *
+GeneralizedTime_encode_json(const struct asn_TYPE_descriptor_s *td, const void *sptr)
+{
+	const GeneralizedTime_t *st = (const GeneralizedTime_t *)sptr;
+	char buf[ASN_TM_STR_MAXLEN];
+
+	if (st == NULL || st->buf == NULL)
+		return json_null();
+
+	if (GeneralizedTime2str(st, buf) < 0)
+		return NULL;
+
+	return json_str_new(buf);
+}
+
 #ifndef	ASN___INTERNAL_TEST_MODE
 
 asn_enc_rval_t
 GeneralizedTime_encode_xer(const asn_TYPE_descriptor_t *td, const void *sptr,
-                           int ilevel, enum xer_encoder_flags_e flags,
+                           int ilevel, int flags,
                            asn_app_consume_bytes_f *cb, void *app_key) {
     if(flags & XER_F_CANONICAL) {
 		GeneralizedTime_t *gt;
@@ -161,7 +170,7 @@ GeneralizedTime_encode_xer(const asn_TYPE_descriptor_t *td, const void *sptr,
 					&fv, &fd, &tm) != 0)
 			ASN__ENCODE_FAILED;
 
-		gt = asn_time2GT_frac(0, &tm, fv, fd);
+		gt = asn_time2GT_frac(NULL, &tm, fv, fd);
 		if(!gt) ASN__ENCODE_FAILED;
 	
 		rv = OCTET_STRING_encode_xer_utf8(td, sptr, ilevel, flags,
@@ -178,34 +187,40 @@ GeneralizedTime_encode_xer(const asn_TYPE_descriptor_t *td, const void *sptr,
 
 int
 GeneralizedTime_print(const asn_TYPE_descriptor_t *td, const void *sptr,
-                      int ilevel, asn_app_consume_bytes_f *cb, void *app_key) {
-    const GeneralizedTime_t *st = (const GeneralizedTime_t *)sptr;
+    int ilevel, asn_app_consume_bytes_f *cb, void *app_key)
+{
+	const GeneralizedTime_t *st = (const GeneralizedTime_t *)sptr;
+	char buf[ASN_TM_STR_MAXLEN];
+	int ret;
 
-	(void)td;	/* Unused argument */
-	(void)ilevel;	/* Unused argument */
-
-	if(st && st->buf) {
-		char buf[32];
-		struct tm tm;
-		int ret;
-
-		if(asn_GT2time(st, &tm) != 0)
-			return (cb("<bad-value>", 11, app_key) < 0) ? -1 : 0;
-
-		ret = snprintf(buf, sizeof(buf),
-			"%04d-%02d-%02d %02d:%02d:%02d (GMT)",
-			tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
-			tm.tm_hour, tm.tm_min, tm.tm_sec);
-		assert(ret > 0 && ret < (int)sizeof(buf));
-		return (cb(buf, ret, app_key) < 0) ? -1 : 0;
-	} else {
+	if (st == NULL || st->buf == NULL)
 		return (cb("<absent>", 8, app_key) < 0) ? -1 : 0;
-	}
+
+	ret = GeneralizedTime2str(st, buf);
+	if (ret < 0)
+		return (cb("<bad-value>", 11, app_key) < 0) ? -1 : 0;
+
+	return (cb(buf, ret, app_key) < 0) ? -1 : 0;
+}
+
+/* Returns string length (ASN_TM_STR_MAXLEN - 1); no errors possible. */
+int
+asn_tm2str(struct tm *tm, char *str)
+{
+	int ret;
+
+	ret = snprintf(str, ASN_TM_STR_MAXLEN,
+		"%04d-%02d-%02d %02d:%02d:%02dZ",
+		tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
+		tm->tm_hour, tm->tm_min, tm->tm_sec);
+	assert(ret == ASN_TM_STR_MAXLEN - 1);
+
+	return ret;
 }
 
 int
 asn_GT2time(const GeneralizedTime_t *st, struct tm *ret_tm) {
-	return asn_GT2time_frac(st, 0, 0, ret_tm);
+	return asn_GT2time_frac(st, NULL, NULL, ret_tm);
 }
 
 time_t
@@ -216,7 +231,7 @@ asn_GT2time_prec(const GeneralizedTime_t *st, int *frac_value, int frac_digits,
 	if(frac_value)
 		tloc = asn_GT2time_frac(st, &fv, &fd, ret_tm);
 	else
-		return asn_GT2time_frac(st, 0, 0, ret_tm);
+		return asn_GT2time_frac(st, NULL, NULL, ret_tm);
 	if(fd == 0 || frac_digits <= 0) {
 		*frac_value = 0;
 	} else {
@@ -423,12 +438,12 @@ asn_time2GT_frac(GeneralizedTime_t *opt_gt, const struct tm *tm, int frac_value,
 	/* Check arguments */
 	if(!tm) {
 		errno = EINVAL;
-		return 0;
+		return NULL;
 	}
 
 	/* Pre-allocate a buffer of sufficient yet small length */
 	buf = (char *)MALLOC(buf_size);
-	if(!buf) return 0;
+	if(!buf) return NULL;
 
 	size = snprintf(buf, buf_size, "%04d%02d%02d%02d%02d%02d",
 		tm->tm_year + 1900,
@@ -442,7 +457,7 @@ asn_time2GT_frac(GeneralizedTime_t *opt_gt, const struct tm *tm, int frac_value,
 		/* Could be assert(size == 14); */
 		FREEMEM(buf);
 		errno = EINVAL;
-		return 0;
+		return NULL;
 	}
 
 	p = buf + size;
@@ -466,7 +481,7 @@ asn_time2GT_frac(GeneralizedTime_t *opt_gt, const struct tm *tm, int frac_value,
 
 		do {
 			int digit = frac_value / fbase;
-			if(digit > 9) { z = 0; break; }
+			if(digit > 9) { z = NULL; break; }
 			*z++ = digit + 0x30;
 			frac_value %= fbase;
 			fbase /= 10;
@@ -487,7 +502,7 @@ asn_time2GT_frac(GeneralizedTime_t *opt_gt, const struct tm *tm, int frac_value,
 			FREEMEM(opt_gt->buf);
 	} else {
 		opt_gt = (GeneralizedTime_t *)CALLOC(1, sizeof *opt_gt);
-		if(!opt_gt) { FREEMEM(buf); return 0; }
+		if(!opt_gt) { FREEMEM(buf); return NULL; }
 	}
 
 	opt_gt->buf = (unsigned char *)buf;
@@ -496,38 +511,6 @@ asn_time2GT_frac(GeneralizedTime_t *opt_gt, const struct tm *tm, int frac_value,
 	return opt_gt;
 }
 
-asn_random_fill_result_t
-GeneralizedTime_random_fill(const asn_TYPE_descriptor_t *td, void **sptr,
-                              const asn_encoding_constraints_t *constraints,
-                              size_t max_length) {
-    asn_random_fill_result_t result_ok = {ARFILL_OK, 1};
-    asn_random_fill_result_t result_failed = {ARFILL_FAILED, 0};
-    asn_random_fill_result_t result_skipped = {ARFILL_SKIPPED, 0};
-    static const char *values[] = {
-        "19700101000000",    "19700101000000-0000",   "19700101000000+0000",
-        "19700101000000Z",   "19700101000000.3Z",     "19821106210623.3",
-        "19821106210629.3Z", "19691106210827.3-0500", "19821106210629.456",
-    };
-    size_t rnd = asn_random_between(0, sizeof(values)/sizeof(values[0])-1);
-
-    (void)constraints;
-
-    if(max_length < sizeof("yyyymmddhhmmss") && !*sptr) {
-        return result_skipped;
-    }
-
-    if(*sptr) {
-        if(OCTET_STRING_fromBuf(*sptr, values[rnd], -1) != 0) {
-            if(!sptr) return result_failed;
-        }
-    } else {
-        *sptr = OCTET_STRING_new_fromBuf(td, values[rnd], -1);
-        if(!sptr) return result_failed;
-    }
-
-    return result_ok;
-}
-
 int
 GeneralizedTime_compare(const asn_TYPE_descriptor_t *td, const void *aptr,
                         const void *bptr) {
@@ -547,10 +530,10 @@ GeneralizedTime_compare(const asn_TYPE_descriptor_t *td, const void *aptr,
         time_t at, bt;
 
         errno = EPERM;
-        at = asn_GT2time_frac(a, &afrac_value, &afrac_digits, 0);
+        at = asn_GT2time_frac(a, &afrac_value, &afrac_digits, NULL);
         aerr = errno;
         errno = EPERM;
-        bt = asn_GT2time_frac(b, &bfrac_value, &bfrac_digits, 0);
+        bt = asn_GT2time_frac(b, &bfrac_value, &bfrac_digits, NULL);
         berr = errno;
 
         if(at == -1 && aerr != EPERM) {
