@@ -15,10 +15,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 enum asn_tag_class {
 	ASN_TAG_CLASS_UNIVERSAL		= 0,	/* 0b00 */
 	ASN_TAG_CLASS_APPLICATION	= 1,	/* 0b01 */
@@ -63,8 +59,4 @@ ssize_t ber_fetch_tag(const void *bufptr, size_t size, ber_tlv_tag_t *tag_r);
  */
 size_t ber_tlv_tag_serialize(ber_tlv_tag_t tag, void *bufptr, size_t size);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif	/* _BER_TLV_TAG_H_ */
