@@ -1,9 +1,7 @@
 #include "asn1/content_info.h"
 
-#include "asn1/asn1c/ContentType.h"
 #include "asn1/decode.h"
 #include "asn1/oid.h"
-#include "file.h"
 #include "log.h"
 
 static int
