@@ -3,10 +3,7 @@
 #include <errno.h>
 #include <sys/queue.h>
 
-#include "alloc.h"
-#include "data_structure/array_list.h"
-#include "object/name.h"
-#include "resource.h"
+#include "log.h"
 #include "str_token.h"
 #include "thread_var.h"
 
