@@ -7,14 +7,12 @@
  * FORT Run mode
  */
 enum mode {
-	/**
-	 * Run as an RTR server
-	 */
+	/* Run as RTR server */
 	SERVER,
-	/*
-	 * Run standalone validation (run validation once and exit)
-	 */
+	/* Run standalone validation (run validation once and exit) */
 	STANDALONE,
+	/* Print file in standard output */
+	PRINT_FILE,
 };
 
 extern const struct global_type gt_mode;
