@@ -1,7 +1,6 @@
 #ifndef SRC_CONFIG_STRING_ARRAY_H_
 #define SRC_CONFIG_STRING_ARRAY_H_
 
-#include <stddef.h>
 #include "config/types.h"
 
 struct string_array {
@@ -12,7 +11,6 @@ struct string_array {
 
 extern const struct global_type gt_string_array;
 
-int string_array_init(struct string_array *, char const *const *, size_t);
-void string_array_cleanup(struct string_array *);
+void string_array_init(struct string_array *, char const *const *, size_t);
 
 #endif /* SRC_CONFIG_STRING_ARRAY_H_ */
