@@ -1,7 +1,5 @@
 #include "http/http.h"
 
-#include <curl/curl.h>
-
 #include "cache/local_cache.h"
 #include "common.h"
 #include "config.h"
@@ -78,6 +76,20 @@ setopt_long(CURL *curl, CURLoption opt, long value)
 	}
 }
 
+static void
+setopt_curlofft(CURL *curl, CURLoption opt, curl_off_t value)
+{
+	CURLcode result;
+
+	result = curl_easy_setopt(curl, opt, value);
+	if (result != CURLE_OK) {
+		fprintf(stderr,
+		    "curl_easy_setopt(%d, %" CURL_FORMAT_CURL_OFF_T
+		    ") returned %d: %s\n",
+		    opt, value, result, curl_easy_strerror(result));
+	}
+}
+
 struct write_callback_arg {
 	size_t total_bytes;
 	int error;
@@ -164,7 +176,7 @@ http_easy_init(struct http_handler *handler, curl_off_t ims)
 	    config_get_http_low_speed_limit());
 	setopt_long(result, CURLOPT_LOW_SPEED_TIME,
 	    config_get_http_low_speed_time());
-	setopt_long(result, CURLOPT_MAXFILESIZE,
+	setopt_curlofft(result, CURLOPT_MAXFILESIZE_LARGE,
 	    config_get_http_max_file_size());
 	setopt_writefunction(result);
 
@@ -230,8 +242,8 @@ validate_file_size(char const *uri, struct write_callback_arg *args)
 	}
 
 	ratio = args->total_bytes / (float) config_get_http_max_file_size();
-	if (ratio > 0.5f) {
-		pr_op_warn("File size exceeds 50%% of the configured limit (%zu/%ld bytes).",
+	if (ratio > 0.4f) {
+		pr_op_warn("File size exceeds 40%% of the configured limit (%zu/%ld bytes).",
 		    args->total_bytes, config_get_http_max_file_size());
 	}
 
