@@ -3,11 +3,9 @@
 #include "config.h"
 #include "extension.h"
 #include "http/http.h"
-#include "incidence/incidence.h"
 #include "log.h"
 #include "nid.h"
 #include "print_file.h"
-#include "rtr/db/vrps.h"
 #include "rtr/rtr.h"
 #include "thread_var.h"
 #include "xml/relax_ng.h"
