@@ -1,7 +1,7 @@
-#include "primitive_writer.h"
+#include "rtr/primitive_writer.h"
 
 unsigned char *
-write_int8(unsigned char *buf, uint8_t value)
+write_uint8(unsigned char *buf, uint8_t value)
 {
 	buf[0] = value;
 	return buf + 1;
@@ -9,7 +9,7 @@ write_int8(unsigned char *buf, uint8_t value)
 
 /** Big Endian. */
 unsigned char *
-write_int16(unsigned char *buf, uint16_t value)
+write_uint16(unsigned char *buf, uint16_t value)
 {
 	buf[0] = value >> 8;
 	buf[1] = value;
@@ -18,7 +18,7 @@ write_int16(unsigned char *buf, uint16_t value)
 
 /** Big Endian. */
 unsigned char *
-write_int32(unsigned char *buf, uint32_t value)
+write_uint32(unsigned char *buf, uint32_t value)
 {
 	buf[0] = value >> 24;
 	buf[1] = value >> 16;
@@ -30,15 +30,14 @@ write_int32(unsigned char *buf, uint32_t value)
 unsigned char *
 write_in_addr(unsigned char *buf, struct in_addr value)
 {
-	return write_int32(buf, ntohl(value.s_addr));
+	return write_uint32(buf, ntohl(value.s_addr));
 }
 
 unsigned char *
-write_in6_addr(unsigned char *buf, struct in6_addr value)
+write_in6_addr(unsigned char *buf, struct in6_addr const *value)
 {
 	int i;
 	for (i = 0; i < 16; i++)
-		buf = write_int8(buf, value.s6_addr[i]);
-
+		buf = write_uint8(buf, value->s6_addr[i]);
 	return buf;
 }
