@@ -1,8 +1,6 @@
 #include "sorted_array.h"
 
-#include <errno.h>
-#include <stdlib.h>
-#include <string.h>
+#include "alloc.h"
 #include "log.h"
 
 struct sorted_array {
@@ -24,15 +22,9 @@ sarray_create(size_t elem_size, sarray_cmp cmp)
 {
 	struct sorted_array *result;
 
-	result = malloc(sizeof(struct sorted_array));
-	if (result == NULL)
-		return NULL;
+	result = pmalloc(sizeof(struct sorted_array));
 
-	result->array = calloc(8, elem_size);
-	if (result->array == NULL) {
-		free(result);
-		return NULL;
-	}
+	result->array = pcalloc(8, elem_size);
 	result->count = 0;
 	result->len = 8;
 	result->size = elem_size;
@@ -60,7 +52,7 @@ sarray_put(struct sorted_array *sarray)
 
 /* Does not check boundaries. */
 static void *
-get_nth_element(struct sorted_array *sarray, unsigned int index)
+get_nth_element(struct sorted_array const *sarray, unsigned int index)
 {
 	return ((char *)sarray->array) + index * sarray->size;
 }
@@ -71,7 +63,7 @@ get_nth_element(struct sorted_array *sarray, unsigned int index)
  * @array.)
  */
 static int
-compare(struct sorted_array *sarray, void *new)
+compare(struct sorted_array *sarray, void const *new)
 {
 	enum sarray_comparison cmp;
 
@@ -102,20 +94,17 @@ compare(struct sorted_array *sarray, void *new)
 }
 
 int
-sarray_add(struct sorted_array *sarray, void *element)
+sarray_add(struct sorted_array *sarray, void const *element)
 {
 	int error;
-	void *tmp;
 
 	error = compare(sarray, element);
 	if (error)
 		return error;
 
 	if (sarray->count >= sarray->len) {
-		tmp = realloc(sarray->array, 2 * sarray->len * sarray->size);
-		if (tmp == NULL)
-			return pr_enomem();
-		sarray->array = tmp;
+		sarray->array = realloc(sarray->array,
+		    2 * sarray->len * sarray->size);
 		sarray->len *= 2;
 	}
 
@@ -125,13 +114,13 @@ sarray_add(struct sorted_array *sarray, void *element)
 }
 
 bool
-sarray_empty(struct sorted_array *sarray)
+sarray_empty(struct sorted_array const *sarray)
 {
 	return (sarray == NULL) || (sarray->count == 0);
 }
 
 bool
-sarray_contains(struct sorted_array *sarray, void *elem)
+sarray_contains(struct sorted_array const *sarray, void const *elem)
 {
 	unsigned int left, mid, right;
 	enum sarray_comparison cmp;
